==> haskell-optparse-simple-0.1.1.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.1.1
id: optparse-simple-0.1.1.1-BdE3FbQCDTpH40boBPU6bT
key: optparse-simple-0.1.1.1-BdE3FbQCDTpH40boBPU6bT
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: a4d6afe0bf07f69c297fea0198863968
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-simple-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-simple-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/optparse-simple-0.1.1.1
hs-libraries: HSoptparse-simple-0.1.1.1-BdE3FbQCDTpH40boBPU6bT
depends:
    base-4.12.0.0 githash-0.1.3.1-2RZcUAVcImXCb6zdvY8gi1
    optparse-applicative-0.14.3.0-AwM1RtrCATI1yFTHqiSLSy
    template-haskell-2.14.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1.1-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.1.1
id: optparse-simple-0.1.1.1-3QE3ra85Oph4YGNlQ18yQH
key: optparse-simple-0.1.1.1-3QE3ra85Oph4YGNlQ18yQH
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: 5158003b6b35a54307c3c70e25da7f66
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-simple-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-simple-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/optparse-simple-0.1.1.1
hs-libraries: HSoptparse-simple-0.1.1.1-3QE3ra85Oph4YGNlQ18yQH
depends:
    base-4.12.0.0 githash-0.1.3.1-4ZRl7H3p7DD2ATWTGz1Ubr
    optparse-applicative-0.14.3.0-6K67dnjFISmWjyySSwRel
    template-haskell-2.14.0.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
